==> haskell-http-common-0.8.3.4-221-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-HmOIAYJS0lkK1hlEHYduw5
key:                  http-common-0.8.3.4-HmOIAYJS0lkK1hlEHYduw5
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  70cf31634eb45eb59d65728721296e76
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-HmOIAYJS0lkK1hlEHYduw5
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-IbCUnYF5PxIJ57HxqijudZ
    blaze-builder-0.4.3-CCGWpBjxAylCkXXKn5PO27 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-JGcld4v8YDLG9iCNMxqnvW directory-1.3.7.1
    mtl-2.2.2 network-3.1.4.0-9WwAYDZyp2nAB4XV6sI63l
    random-1.2.1.3-5GClgMcgHINEWJGyng3KHI text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-obNV32ZSreHxgWRz6JrKP

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-common-0.8.3.4-222-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-common.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-common
version:              0.8.3.4
visibility:           public
id:                   http-common-0.8.3.4-5mY6yOBXH1M3oLDvS1ZLCQ
key:                  http-common-0.8.3.4-5mY6yOBXH1M3oLDvS1ZLCQ
license:              BSD-3-Clause
copyright:            © 2012-2021 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-common
synopsis:             Common types for HTTP clients and servers
description:
    /Overview/

    Base types used by a variety of HTTP clients and servers. See http-streams
    "Network.Http.Client" or pipes-http "Pipes.Http.Client" for full
    documentation. You can import @Network.Http.Types@ if you like, but both
    http-streams and pipes-http re-export this package'\''s types and functions.

category:             Web
abi:                  5801beb11f9442fd0f72a7e643fc3b01
exposed:              True
exposed-modules:
    Network.Http.Internal Network.Http.RequestBuilder
    Network.Http.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-common-0.8.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-common
hs-libraries:         HShttp-common-0.8.3.4-5mY6yOBXH1M3oLDvS1ZLCQ
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-ALlNDgCJ5uI9xkCg0LJBoH
    blaze-builder-0.4.3-BgDmm9LLPQj70kDL41wf1H bytestring-0.11.5.3
    case-insensitive-1.2.1.0-K9RqmTXohzcArWLcYT3z8C directory-1.3.7.1
    mtl-2.2.2 network-3.1.4.0-JHT56NFIotXJvLJoz7gUbr
    random-1.2.1.3-G8HhURP50mfDOIe4gICdYG text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-5ChD9TF8iAH5uLARI0QLMz

haddock-interfaces:   /usr/share/doc/haskell-http-common/html/http-common.haddock
haddock-html:         /usr/share/doc/haskell-http-common/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
